@@ -28,5 +28,5 @@ propmiss <- function(df) {
     d$var <- row.names(d)
     row.names(d) <- NULL
     d <- cbind(d[ncol(d)],d[-ncol(d)])
-    return(d[order(d$propmiss), ])
+    return(d)
 }
\ No newline at end of file
